============
 User Guide
============

.. highlight:: ditzsession

This section presents a simple tutorial of how to use |PD|, and gives some
idea of how it works along the way.

.. toctree::
   :maxdepth: 2

   guide/start.rst
   guide/create.rst
   guide/query.rst
   guide/assign.rst
   guide/issues.rst
   guide/editing.rst
   guide/release.rst
   guide/export.rst
   guide/other.rst
   guide/vcs.rst
   guide/config.rst
   guide/database.rst
